@@ -1,6 +1,9 @@
 from fa_purity.maybe import (
     Maybe,
 )
+from fa_purity.utils import (
+    raise_exception,
+)
 from redshift_client.data_type.alias import (
     NON_STC_ALIAS_MAP,
     STC_ALIAS_MAP,
@@ -33,16 +36,19 @@ def _get_enum(cast: Callable[[_T], _R], val: _T) -> Maybe[_R]:
 def decode_type(
     raw: str, precision: Maybe[int], scale: Maybe[int]
 ) -> DataType:
-    dtype: Maybe[DataType] = Maybe.from_optional(STC_ALIAS_MAP.get(raw)).lash(
-        lambda: _get_enum(StaticTypes, raw).map(DataType)
+    _raw = raw.upper()
+    dtype: Maybe[DataType] = Maybe.from_optional(STC_ALIAS_MAP.get(_raw)).lash(
+        lambda: _get_enum(StaticTypes, _raw).map(DataType)
     )
     if dtype.value_or(None):
         return dtype.unwrap()
     incomplete_type: NonStcDataTypes = (
-        Maybe.from_optional(NON_STC_ALIAS_MAP.get(raw))
-        .lash(lambda: _get_enum(PrecisionTypes, raw).map(NonStcDataTypes))
-        .lash(lambda: _get_enum(ScaleTypes, raw).map(NonStcDataTypes))
-        .unwrap()
+        Maybe.from_optional(NON_STC_ALIAS_MAP.get(_raw))
+        .lash(lambda: _get_enum(PrecisionTypes, _raw).map(NonStcDataTypes))
+        .lash(lambda: _get_enum(ScaleTypes, _raw).map(NonStcDataTypes))
+        .or_else_call(
+            lambda: raise_exception(ValueError(f"Unknown data type: {_raw}"))
+        )
     )
     if isinstance(incomplete_type.value, PrecisionTypes):
         p_result = PrecisionType(incomplete_type.value, precision.unwrap())
