@@ -34,13 +34,17 @@ class Query:
     _inner: _Query
 
 
-def new_query(statement: str) -> Query:
-    draft = _Query(SQL(statement))
+def _pretty(raw: str) -> str:
+    return " ".join(raw.strip(" \n\t").split())
+
+
+def new_query(stm: str) -> Query:
+    draft = _Query(SQL(_pretty(stm)))
     return Query(draft)
 
 
 def dynamic_query(
-    statement: str, identifiers: FrozenDict[str, Optional[str]]
+    stm: str, identifiers: FrozenDict[str, Optional[str]]
 ) -> Query:
-    draft = _Query(_purifier(statement, identifiers))
+    draft = _Query(_purifier(_pretty(stm), identifiers))
     return Query(draft)
