@@ -3,6 +3,7 @@ from dataclasses import (
 )
 from fa_purity.frozen import (
     FrozenDict,
+    FrozenList,
 )
 from fa_purity.result import (
     Result,
@@ -20,6 +21,7 @@ from typing import (
 
 @dataclass(frozen=True)
 class _Table:
+    order: FrozenList[ColumnId]
     columns: FrozenDict[ColumnId, Column]
     primary_keys: FrozenSet[ColumnId]
 
@@ -27,15 +29,16 @@ class _Table:
 @dataclass(frozen=True)
 class Table(_Table):
     def __init__(self, obj: _Table) -> None:
-        super().__init__(obj.columns, obj.primary_keys)
+        super().__init__(obj.order, obj.columns, obj.primary_keys)
 
 
 def new(
+    order: FrozenList[ColumnId],
     columns: FrozenDict[ColumnId, Column],
     primary_keys: FrozenSet[ColumnId],
 ) -> ResultE[Table]:
     in_columns: Callable[[ColumnId], bool] = lambda k: k in columns
     if all(map(in_columns, primary_keys)):
-        draft = _Table(columns, primary_keys)
+        draft = _Table(order, columns, primary_keys)
         return Result.success(Table(draft))
     return Result.failure(Exception("All primary keys must be in columns"))
